---
title: <span class="badge object-type-scalar"></span> SquareMeters
---
# <span class="badge object-type-scalar"></span> SquareMeters

Area: Square Meters (m²)

## Definition

```python
# Area: Square Meters (m²)
SquareMeters: typing.Literal["areaM2"] = "areaM2"
```
